@@ -201,7 +201,7 @@ blocks <- function(lb, ls, matdata, pardata1, pardata2, stpairs) {
   # == Some checks on class of data ==#
   # ==================================#
 
-  if (class(matdata) == "matrix" || class(matdata) == "data.frame") {
+  if (is(matdata, "matrix") || is(matdata, "data.frame")) {
     iclsp.id <- as.integer(pardata1)
     iclvr <- as.integer(pardata2)
   }
@@ -214,7 +214,7 @@ blocks <- function(lb, ls, matdata, pardata1, pardata2, stpairs) {
                                     length = length(selstaz))
     for (i in 1:length(selstaz)) {
       ### data in GSLIB format###
-      if (class(matdata) == "matrix" || class(matdata) == "data.frame") {
+      if (is(matdata, "matrix") || is(matdata, "data.frame")) {
         if (i == 1) {
           selstaz.names <- matdata[, iclsp.id]
         selstaz.inter <- intersect(selstaz.names, selstaz)
@@ -233,7 +233,7 @@ blocks <- function(lb, ls, matdata, pardata1, pardata2, stpairs) {
       } else {
 
         ### data in gstat format###
-        if (class(matdata) == "STFDF") {
+        if (is(matdata, "STFDF")) {
           if (i == 1) {
             selstaz.names <- row.names(matdata@sp)
             selstaz.inter <- intersect(selstaz.names, selstaz)
@@ -255,7 +255,7 @@ blocks <- function(lb, ls, matdata, pardata1, pardata2, stpairs) {
 
 
           ### data in gstat format###
-          if (class(matdata) == "STSDF") {
+          if (is(matdata, "STSDF")) {
             matdata <- as(matdata, "STFDF")
             if (i == 1) {
               selstaz.names <- row.names(matdata@sp)
